@@ -18,7 +18,7 @@
 #define ZDICT_STATIC_LINKING_ONLY
 
 #ifdef ZSTD_SINGLE_FILE
-#include <zstdlib.c>
+#include <zstd.c>
 
 /* We use private APIs from pool.h. We can't rely on availability
    of this header or symbols when linking against the system libzstd.
@@ -31,7 +31,7 @@
 
 /* Remember to change the string in zstandard/__init__.py, rust-ext/src/lib.rs,
    and debian/changelog as well */
-#define PYTHON_ZSTANDARD_VERSION "0.18.0"
+#define PYTHON_ZSTANDARD_VERSION "0.20.0"
 
 typedef enum {
     compressorobj_flush_finish,
