@@ -4,8 +4,6 @@
 // This software may be modified and distributed under the terms
 // of the BSD license. See the LICENSE file for details.
 
-#![feature(try_reserve)]
-
 use pyo3::{prelude::*, types::PySet};
 
 mod buffers;
@@ -32,7 +30,9 @@ mod zstd_safe;
 
 use exceptions::ZstdError;
 
-const VERSION: &'static str = "0.15.2";
+// Remember to change the string in c-ext/python-zstandard.h, zstandard/__init__.py,
+// and debian/changelog as well.
+const VERSION: &'static str = "0.20.0";
 
 #[pymodule]
 fn backend_rust(py: Python, module: &PyModule) -> PyResult<()> {
